/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
export declare namespace ShopperLoginSlasAdmin {
  type SimpleClient = {
    clientId: string;
    clientName: string;
    clientType: string;
    scope: Array<string>;
    redirectUri: string;
    channels: Array<string>;
  } & {
    [key: string]: any;
  };
  type Tenant = {
    tenantInstance: string;
    merchantName: string;
    tenantDescription: string;
    tenantContact: string;
    emailAddress: string;
    phoneNo: string;
  } & {
    [key: string]: any;
  };
  type ClientRequest = {
    clientName: string;
    ecomTenant: string;
    oauthClientId: string;
    oauthClientSecret: string;
    ecomSite: string;
    scopes: Array<string>;
    redirectUri: string;
    channels: Array<string>;
    privateClient: boolean;
  } & {
    [key: string]: any;
  };
  type IdentityProvider = {
    idpName: string;
    idpAuthUrl: string;
    idpTokenUrl: string;
    idpTokenInfoUrl: string;
    idpUserinfoUrl: string;
    idpRedirectUrl: string;
    idpClientId: string;
    idpClientSecret: string;
    idpPreferenceValue: boolean;
  } & {
    [key: string]: any;
  };
  type Client = {
    clientId: string;
    clientName: string;
    clientType: string;
    clientSecret: string;
    scope: Array<string>;
    redirectUri: string;
    channels: Array<string>;
    privateClient: boolean;
  } & {
    [key: string]: any;
  };
  type ErrorResponse = {
    type: string;
    title?: string;
    detail?: string;
    instance?: string;
  } & {
    [key: string]: any;
  };
}
/**
* [Shopper Login and API Access Admin](https://developer.commercecloud.com/s/api-details/a003k00000Wa43QAAR)
* ==================================
*
* *Enable administrators to set up tenants, clients and identity providers for shopper login*<br />
*
* Simple example:
*
* ```typescript
*   import { Customer, ClientConfig } from "commerce-sdk";
*   // or
*   const { Customer, ClientConfig } = require("commerce-sdk");
*
*   const clientConfig: ClientConfig = { ... };
*   const shopperLoginSlasAdminClient = new Customer.ShopperLoginSlasAdmin(clientConfig);
* ```
*
* Example with shopper auth
* ```typescript
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
* token = await helpers.getShopperToken(clientConfig, { type: "guest" });
* clientConfig.headers["authorization"] = token.getBearerHeader();
* const shopperLoginSlasAdminClient = new Customer.ShopperLoginSlasAdmin(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.3.0<br />
* Last Updated: <br />
* </span>
* @beta
*
*

*/
export declare class ShopperLoginSlasAdmin extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Register a tenant
   *
   * If you would like to get a raw Response object use the other registerTenant function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.Tenant.
   *
   * @beta
   *
   */
  registerTenant(options: {
    parameters?: {};
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperLoginSlasAdmin.Tenant;
  }): Promise<ShopperLoginSlasAdmin.Tenant>;
  /**
   * Register a tenant
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.Tenant otherwise.
   *
   * @beta
   *
   */
  registerTenant<T extends boolean>(
    options: {
      parameters?: {};
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperLoginSlasAdmin.Tenant;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperLoginSlasAdmin.Tenant>;
  /**
   * Retrieve a list of tenants
   *
   * If you would like to get a raw Response object use the other retrieveTenants function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.Tenant.
   *
   * @beta
   *
   */
  retrieveTenants(options?: {
    parameters?: {};
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperLoginSlasAdmin.Tenant>;
  /**
   * Retrieve a list of tenants
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.Tenant otherwise.
   *
   * @beta
   *
   */
  retrieveTenants<T extends boolean>(
    options?: {
      parameters?: {};
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperLoginSlasAdmin.Tenant>;
  /**
   * Retrieve a tenant by tenant id
   *
   * If you would like to get a raw Response object use the other retrieveTenant function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.Tenant.
   *
   * @beta
   *
   */
  retrieveTenant(options?: {
    parameters?: {
      tenantId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperLoginSlasAdmin.Tenant>;
  /**
   * Retrieve a tenant by tenant id
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.Tenant otherwise.
   *
   * @beta
   *
   */
  retrieveTenant<T extends boolean>(
    options?: {
      parameters?: {
        tenantId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperLoginSlasAdmin.Tenant>;
  /**
   * Update a tenant by tenant id. Updates tenant description, tenant contact, email address, and phone number.
   *
   * If you would like to get a raw Response object use the other updateTenant function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.Tenant.
   *
   * @beta
   *
   */
  updateTenant(options: {
    parameters?: {
      tenantId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<ShopperLoginSlasAdmin.Tenant>;
  /**
   * Update a tenant by tenant id. Updates tenant description, tenant contact, email address, and phone number.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.Tenant otherwise.
   *
   * @beta
   *
   */
  updateTenant<T extends boolean>(
    options: {
      parameters?: {
        tenantId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: object;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperLoginSlasAdmin.Tenant>;
  /**
   * Delete a tenant
   *
   * If you would like to get a raw Response object use the other deleteTenant function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   *
   * @beta
   *
   */
  deleteTenant(options?: {
    parameters?: {
      tenantId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Delete a tenant
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   * @beta
   *
   */
  deleteTenant<T extends boolean>(
    options?: {
      parameters?: {
        tenantId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Retrieve/Get all tenant clients
   *
   * If you would like to get a raw Response object use the other retrieveClients function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.Client.
   *
   * @beta
   *
   */
  retrieveClients(options?: {
    parameters?: {
      tenantId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperLoginSlasAdmin.Client>;
  /**
   * Retrieve/Get all tenant clients
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.Client otherwise.
   *
   * @beta
   *
   */
  retrieveClients<T extends boolean>(
    options?: {
      parameters?: {
        tenantId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperLoginSlasAdmin.Client>;
  /**
   * Create/Register a new client
   *
   * If you would like to get a raw Response object use the other registerClient function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.Client.
   *
   * @beta
   *
   */
  registerClient(options: {
    parameters?: {
      tenantId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperLoginSlasAdmin.ClientRequest;
  }): Promise<ShopperLoginSlasAdmin.Client>;
  /**
   * Create/Register a new client
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.Client otherwise.
   *
   * @beta
   *
   */
  registerClient<T extends boolean>(
    options: {
      parameters?: {
        tenantId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperLoginSlasAdmin.ClientRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperLoginSlasAdmin.Client>;
  /**
   * Retrieve/Get a new client
   *
   * If you would like to get a raw Response object use the other retrieveClient function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param clientId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.Client.
   *
   * @beta
   *
   */
  retrieveClient(options?: {
    parameters?: {
      tenantId: string;
      clientId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperLoginSlasAdmin.Client>;
  /**
   * Retrieve/Get a new client
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param clientId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.Client otherwise.
   *
   * @beta
   *
   */
  retrieveClient<T extends boolean>(
    options?: {
      parameters?: {
        tenantId: string;
        clientId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperLoginSlasAdmin.Client>;
  /**
   * Update/Change a new client
   *
   * If you would like to get a raw Response object use the other updateClient function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param clientId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.Client.
   *
   * @beta
   *
   */
  updateClient(options: {
    parameters?: {
      tenantId: string;
      clientId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperLoginSlasAdmin.ClientRequest;
  }): Promise<ShopperLoginSlasAdmin.Client>;
  /**
   * Update/Change a new client
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param clientId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.Client otherwise.
   *
   * @beta
   *
   */
  updateClient<T extends boolean>(
    options: {
      parameters?: {
        tenantId: string;
        clientId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperLoginSlasAdmin.ClientRequest;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ShopperLoginSlasAdmin.Client>;
  /**
   * Delete a client
   *
   * If you would like to get a raw Response object use the other deleteClient function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param clientId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   *
   * @beta
   *
   */
  deleteClient(options?: {
    parameters?: {
      tenantId: string;
      clientId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Delete a client
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param clientId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   * @beta
   *
   */
  deleteClient<T extends boolean>(
    options?: {
      parameters?: {
        tenantId: string;
        clientId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Retrieve/Get all tenant identity providers
   *
   * If you would like to get a raw Response object use the other retrieveIdentityProviders function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.IdentityProvider.
   *
   * @beta
   *
   */
  retrieveIdentityProviders(options?: {
    parameters?: {
      tenantId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperLoginSlasAdmin.IdentityProvider>;
  /**
   * Retrieve/Get all tenant identity providers
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.IdentityProvider otherwise.
   *
   * @beta
   *
   */
  retrieveIdentityProviders<T extends boolean>(
    options?: {
      parameters?: {
        tenantId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<
    T extends true ? Response : ShopperLoginSlasAdmin.IdentityProvider
  >;
  /**
   * Register an identity provider
   *
   * If you would like to get a raw Response object use the other registerIdentityProvider function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.IdentityProvider.
   *
   * @beta
   *
   */
  registerIdentityProvider(options: {
    parameters?: {
      tenantId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperLoginSlasAdmin.IdentityProvider;
  }): Promise<ShopperLoginSlasAdmin.IdentityProvider>;
  /**
   * Register an identity provider
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.IdentityProvider otherwise.
   *
   * @beta
   *
   */
  registerIdentityProvider<T extends boolean>(
    options: {
      parameters?: {
        tenantId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperLoginSlasAdmin.IdentityProvider;
    },
    rawResponse?: T
  ): Promise<
    T extends true ? Response : ShopperLoginSlasAdmin.IdentityProvider
  >;
  /**
   * Retrieve/Get a specific identity provider
   *
   * If you would like to get a raw Response object use the other retrieveIdentityProvider function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param idpId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.IdentityProvider.
   *
   * @beta
   *
   */
  retrieveIdentityProvider(options?: {
    parameters?: {
      tenantId: string;
      idpId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ShopperLoginSlasAdmin.IdentityProvider>;
  /**
   * Retrieve/Get a specific identity provider
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param idpId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.IdentityProvider otherwise.
   *
   * @beta
   *
   */
  retrieveIdentityProvider<T extends boolean>(
    options?: {
      parameters?: {
        tenantId: string;
        idpId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<
    T extends true ? Response : ShopperLoginSlasAdmin.IdentityProvider
  >;
  /**
   * Update/Change an identity provider
   *
   * If you would like to get a raw Response object use the other updateIdentityProvider function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param idpId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ShopperLoginSlasAdmin.IdentityProvider.
   *
   * @beta
   *
   */
  updateIdentityProvider(options: {
    parameters?: {
      tenantId: string;
      idpId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ShopperLoginSlasAdmin.IdentityProvider;
  }): Promise<ShopperLoginSlasAdmin.IdentityProvider>;
  /**
   * Update/Change an identity provider
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param idpId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ShopperLoginSlasAdmin.IdentityProvider otherwise.
   *
   * @beta
   *
   */
  updateIdentityProvider<T extends boolean>(
    options: {
      parameters?: {
        tenantId: string;
        idpId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ShopperLoginSlasAdmin.IdentityProvider;
    },
    rawResponse?: T
  ): Promise<
    T extends true ? Response : ShopperLoginSlasAdmin.IdentityProvider
  >;
  /**
   * Delete a identity provider
   *
   * If you would like to get a raw Response object use the other deleteIdentityProvider function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param idpId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   *
   * @beta
   *
   */
  deleteIdentityProvider(options?: {
    parameters?: {
      tenantId: string;
      idpId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Delete a identity provider
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param tenantId -
   * @param idpId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   * @beta
   *
   */
  deleteIdentityProvider<T extends boolean>(
    options?: {
      parameters?: {
        tenantId: string;
        idpId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
}
